************
Astroimtools
************


Astroimtools Overview
=====================

Astroimtools is a Python package that provides convenience tools
for working with astronomical images.  It is an open source (BSD
licensed) Python package.  Bug reports, comments, and help with
development are very welcome.


Getting Started
===============

.. toctree::
    :maxdepth: 1

    install.rst
    contributing.rst
    Code of Conduct <conduct.rst>
    license.rst
    changelog


User Documentation
==================

.. toctree::
    :maxdepth: 1

    stats.rst
    arithmetic.rst
    filtering.rst
    nddata_adapters.rst
    cutouts.rst
    utils.rst
    scripts.rst
